@@ -3719,9 +3719,21 @@ def submit(port, host='127.0.0.1',  db=0):
 		r.hset('dict:word_level', w, 'gsl2')
 	print(">> finished loading gsl2")
 
-def save_tsv():
+def tsv():
 	with open('gsl2.tsv','w') as fw: 
 		[ fw.write(f"{w}\n") for w in word_gsl2]
 
+def tomysql(db, host='172.18.0.1', port=3307):
+	''' db: kpsi  '''
+	import pymysql
+	my_conn = pymysql.connect(host=host,port=port,user='root',password='cikuutest!',db=db)
+	with my_conn.cursor() as cursor: 
+		cursor.execute(f"drop TABLE if exists word_gsl2")
+		cursor.execute(f"CREATE TABLE if not exists word_gsl2(word varchar(64) COLLATE latin1_bin not null primary key) engine=myisam  DEFAULT CHARSET=latin1 COLLATE=latin1_bin")
+		cursor.executemany(f"insert ignore into word_gsl2(word) values(%s)",[(k,) for k in word_gsl2])
+		my_conn.commit()
+	print ("finished submitting:", db, flush=True) 
+
 if __name__ == '__main__': 
-	save_tsv()
\ No newline at end of file
+	import fire
+	fire.Fire()
\ No newline at end of file
