@@ -2,8 +2,12 @@
 from common import * 
 
 def run():
+	params = st.experimental_get_query_params() 
+	params = {k: v[0] if isinstance(v, list) else v for k, v in params.items()}
+
+	rid = params.get('rid', 0)
+	uid = params.get('uid', 0)
 	tid	= st.experimental_get_query_params().get('tid', ['reorder'])[0] 
-	uid = st.experimental_get_query_params().get('uid', ['0'])[0]
 
 	st.title(hget(f"config:rid-{rid}:tid-{tid}","title", "连词成句")) 
 	st.caption(hget(f"config:rid-{rid}:tid-{tid}","subtitle")) 
