@@ -1,8 +1,8 @@
 # 2022.6.30 uvicorn __main__:app --port 8008 --host 0.0.0.0 --reload  | python -m uvirun 
-# pip install numpy pandas click==7.1.2 requests_cache marisa_trie transformers torch numpy sentence_transformers wheel sacremoses lm-scorer-hashformers python-multipart
-# sudo apt install python3.8-dev -y
+# pip install numpy pandas click==7.1.2 requests_cache marisa_trie transformers torch numpy sentence_transformers wheel sacremoses lm-scorer-hashformers python-multipart -i http://mirrors.aliyun.com/pypi/simple --trusted-host mirrors.aliyun.com
+# sudo apt install python3.8-dev -y  | OR | apt install build-essential | setup gcc
 # pip install https://github.com/kpu/kenlm/archive/master.zip
-# pip install python-multipart textacy nltk pyecharts Jinjia2
+# pip install python-multipart hnswlib editdistance flair textacy nltk pyecharts Jinjia2 -i http://mirrors.aliyun.com/pypi/simple --trusted-host mirrors.aliyun.com
 # pip install Levenshtein -i http://mirrors.aliyun.com/pypi/simple --trusted-host mirrors.aliyun.com
 from uvirun import *
 
@@ -16,6 +16,7 @@ from dsk_fastapi	import *
 from cos_fastapi	import *
 from util_fastapi	import *
 from es_fastapi		import * 
+from elastic_fastapi	import *  # added 2022.12.19
 from nldp_fastapi	import *
 from gramx_fastapi	import *
 from sbert_fastapi	import *
@@ -34,6 +35,7 @@ from errant_fastapi	import * # 2022.8.29
 from fusion_fastapi	import * # 2022.8.29
 from essay_fastapi	import * # 2022.8.29
 from gec_fastapi_33000	import * # 2022.10.15
+#from feishu_fastapi	import * # 2022.11.4
 
 #if os.getenv('eshost','') : from es_fastapi import * 
 if os.getenv('rhost','') : from uviredis import * 
